*********************
Interactive Interface
*********************

The `rail_projects` has a few main entry points for interactive using,
e.g., via jupyter notebooks.  One is a combination of the
`RailProject` class and the functions in the `rail.projects.library`
module, which, together, work with the tools in `rail.projects` and help to manage
analysis projects.   The other is the functions in the
`rail.plotting.control` module, which work with the tools in `rail.plotting`
and help to make plots.


===========================
Using RailProject interface
===========================

.. autoclass:: rail.projects.RailProject
    :noindex:
	       
=====================================
Using rail.projects.library interface
=====================================

.. automodule:: rail.projects.library		
    :members:
    :noindex:
		
=====================================
Using rail.plotting.control interface
=====================================

.. automodule:: rail.plotting.control
    :members:
    :noindex:

